darkhistory.electrons.ics.engloss_diff_terms.engloss_diff_expansion — DarkHistory documentation

# darkhistory.electrons.ics.engloss_diff_terms.engloss_diff_expansion

`darkhistory.electrons.ics.engloss_diff_terms.` `engloss_diff_expansion`(beta, delta, T, as_pairs=False)

  Difference expansion term for the energy loss spectrum.

  Parameters: | beta : ndarray Velocity of the electron. delta : ndarray Energy gained from upscattering by the secondary photon. T : float CMB temperature as_pairs : bool, optional If true, treats eleceng and photeng as a paired list: produces eleceng.size == photeng.size values. Otherwise, gets the spectrum at each photeng for each eleceng, returning an array of length eleceng.size*photeng.size.
  Returns: | ndarray The computed energy loss spectrum

#### Previous topic

darkhistory.electrons.ics.engloss_diff_terms

#### Next topic

darkhistory.electrons.ics.ics_cooling

### This Page

Show Source